@@ -1,10 +1,23 @@
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import Column, Integer, Float, String
-from sqlalchemy_sqlite_session.tools import get_session
+from sqlalchemy import create_engine
+from sqlalchemy.orm import sessionmaker
 
 Base = declarative_base()
 
 
+def get_engine():
+    engine = create_engine('sqlite:///C:\\sqlite\\kl8.db')
+    return engine
+
+
+def get_session():
+    engine = create_engine('sqlite:///C:\\sqlite\\kl8.db')
+    Session = sessionmaker(bind=engine)
+    session = Session()         # 创建Session类实例
+    return session
+
+
 class HappyFollow(Base):
     __tablename__ = 'kl8_follow'
 
@@ -957,6 +970,47 @@ class HappyVerify(Base):
         return whether_train
 
 
+class Power(Base):
+    """ table powers """
+    __tablename__ = 'powers'
+    channel_power_issue = Column(String, primary_key=True)
+    channel = Column(String)
+    power = Column(String)
+    issue = Column(Integer)
+    num10 = Column(String)
+
+    def __init__(self, channel, power, issue, num10):
+        self.channel_power_issue = f'{channel}_{power}_{issue}'
+        self.channel = channel
+        self.power = power
+        self.issue = issue
+        self.num10 = num10
+
+    @classmethod
+    def merge_one(cls, channel, power, issue, num10):
+        """get issues[list]"""
+        session = get_session()
+        ins = cls(channel, power, issue, num10)
+        session.merge(ins)
+        session.commit()
+        session.close()
+        print(f">>>>>> merge one: {channel} - {power} - {issue} - {num10}")
+
+
+class History(Base):
+    __tablename__ = 'historys'
+
+    issue_item = Column(String, primary_key=True)
+    issue = Column(Integer)
+    item = Column(String)
+    score = Column(Float)
+    length_xy = Column(String)
+    length_pr = Column(String)
+
+    def __str__(self) -> str:
+        return f'{self.issue_item}, {self.score}'
+
+
 if __name__ == "__main__":
     # generate tables
     from tools import get_engine
