@@ -67,6 +67,16 @@ class SportNumber(Base):
         result.sort()
         return result
 
+    @classmethod
+    def get_previous_issues_by_num(cls, issue_now, num):
+        all_issues = cls.get_issues()
+        issue_now = int(issue_now)
+        if issue_now in all_issues:
+            index_now = all_issues.index(issue_now)
+            return all_issues[index_now - num: index_now]
+        else:
+            return all_issues[- num:]
+
     @classmethod
     def get_previous3_issues(cls, issue_now):
         all_issues = cls.get_issues()
@@ -897,6 +907,14 @@ class SportNumber5(Base):
         index_now = all_issues.index(issue_now)
         return all_issues[index_now - 3: index_now]
 
+    @classmethod
+    def get_previous_issues_by_num(cls, issue_now, num):
+        all_issues = cls.get_issues()
+        all_issues.sort()
+        issue_now = int(issue_now)
+        index_now = all_issues.index(issue_now)
+        return all_issues[index_now - num: index_now]
+
     @classmethod
     def get_next3_issues(cls, issue_now):
         all_issues = cls.get_issues()
