@@ -4,12 +4,12 @@ from sqlalchemy.orm import sessionmaker
 
 
 def get_engine():
-    engine = create_engine('sqlite:///E:\\sqlite\\all.db')
+    engine = create_engine('sqlite:///C:\\sqlite\\all.db')
     return engine
 
 
 def get_session():
-    engine = create_engine('sqlite:///E:\\sqlite\\all.db')
+    engine = create_engine('sqlite:///C:\\sqlite\\all.db')
     Session = sessionmaker(bind=engine)
     session = Session()         # 创建Session类实例
     return session
