@@ -46,13 +46,13 @@ class WelfareNumber(Base):
 
     @classmethod
     def get_issue_future(cls):
-        """get issues[list]"""
+        """get issue"""
         session = get_session_welfare()
         i = session.query(cls).all()
         session.close()
         last = [x.issue for x in i]
         last.sort()
-        result = last + 1
+        result = last[-1] + 1
         return result
 
     @classmethod
